==> glue-1.93.0-sources.jar: software/amazon/awscdk/services/glue/OutputFormat.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Absolute class name of the Hadoop `OutputFormat` to use when writing table files.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.485Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.OutputFormat")
public class OutputFormat extends software.amazon.jsii.JsiiObject {

    protected OutputFormat(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected OutputFormat(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AVRO = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.OutputFormat.class, "AVRO", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        HIVE_IGNORE_KEY_TEXT = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.OutputFormat.class, "HIVE_IGNORE_KEY_TEXT", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.OutputFormat.class));
        ORC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.OutputFormat.class, "ORC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        PARQUET = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.OutputFormat.class, "PARQUET", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.OutputFormat.class));
    }

    /**
     * @param className This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public OutputFormat(final @org.jetbrains.annotations.NotNull java.lang.String className) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(className, "className is required") });
    }

    /**
     * (experimental) OutputFormat for Avro files.
     * <p>
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/avro/AvroContainerOutputFormat.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat AVRO;

    /**
     * (experimental) Writes text data with a null key (value only).
     * <p>
     * @see https://hive.apache.org/javadocs/r2.2.0/api/org/apache/hadoop/hive/ql/io/HiveIgnoreKeyTextOutputFormat.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.OutputFormat HIVE_IGNORE_KEY_TEXT;

    /**
     * (experimental) OutputFormat for Orc files.
     * <p>
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/orc/OrcOutputFormat.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat ORC;

    /**
     * (experimental) OutputFormat for Parquet files.
     * <p>
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/parquet/MapredParquetOutputFormat.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.OutputFormat PARQUET;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getClassName() {
        return software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> glue-1.182.0-sources.jar: software/amazon/awscdk/services/glue/OutputFormat.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Absolute class name of the Hadoop `OutputFormat` to use when writing table files.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.glue.*;
 * OutputFormat outputFormat = new OutputFormat("className");
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:43.466Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.OutputFormat")
public class OutputFormat extends software.amazon.jsii.JsiiObject {

    protected OutputFormat(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected OutputFormat(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AVRO = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.OutputFormat.class, "AVRO", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        HIVE_IGNORE_KEY_TEXT = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.OutputFormat.class, "HIVE_IGNORE_KEY_TEXT", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.OutputFormat.class));
        ORC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.OutputFormat.class, "ORC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.InputFormat.class));
        PARQUET = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.OutputFormat.class, "PARQUET", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.OutputFormat.class));
    }

    /**
     * @param className This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public OutputFormat(final @org.jetbrains.annotations.NotNull java.lang.String className) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(className, "className is required") });
    }

    /**
     * (experimental) OutputFormat for Avro files.
     * <p>
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/avro/AvroContainerOutputFormat.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/avro/AvroContainerOutputFormat.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat AVRO;

    /**
     * (experimental) Writes text data with a null key (value only).
     * <p>
     * @see <a href="https://hive.apache.org/javadocs/r2.2.0/api/org/apache/hadoop/hive/ql/io/HiveIgnoreKeyTextOutputFormat.html">https://hive.apache.org/javadocs/r2.2.0/api/org/apache/hadoop/hive/ql/io/HiveIgnoreKeyTextOutputFormat.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.OutputFormat HIVE_IGNORE_KEY_TEXT;

    /**
     * (experimental) OutputFormat for Orc files.
     * <p>
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/orc/OrcOutputFormat.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/orc/OrcOutputFormat.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.InputFormat ORC;

    /**
     * (experimental) OutputFormat for Parquet files.
     * <p>
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/parquet/MapredParquetOutputFormat.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/parquet/MapredParquetOutputFormat.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.OutputFormat PARQUET;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getClassName() {
        return software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
